/**
 * 项目：互联网医疗
 * 模型分组：服务管理
 * 模型名称：用户信息表
 * @Author: xiongwei
 * @Date: 2023-09-05 09:42:00
 */

package com.xwd.hospital.server.service.impl;

import com.xwd.hospital.server.dto.CtUserInfoDto;
import com.xwd.hospital.server.rest.res.ApiCode.ApiException;
import java.util.List;
import java.util.Collection;
import com.baomidou.mybatisplus.core.enums.SqlMethod;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.xwd.hospital.server.service.UserInfoService;
import com.xwd.hospital.server.repository.UserInfoMapper;
import com.xwd.hospital.server.repository.base.UserInfoBaseMapper;
import com.xwd.hospital.server.domain.UserInfo;

@Service
public class UserInfoServiceImpl extends ServiceImpl<UserInfoMapper, UserInfo> implements UserInfoService {

    @Override
    public int updateAllFieldsById(UserInfo entity) {
        return this.getBaseMapper().updateAllFieldsById(entity);
    }

    /**
     * 批量插入
     *
     * @param entityList ignore
     * @param batchSize  ignore
     * @return ignore
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean saveBatch(Collection<UserInfo> entityList, int batchSize) {
        String sqlStatement = SqlHelper.getSqlStatement(UserInfoBaseMapper.class, SqlMethod.INSERT_ONE);
        return executeBatch(entityList, batchSize, (sqlSession, entity) -> sqlSession.insert(sqlStatement, entity));
    }


    @Override
    public List<UserInfo> queryUserInfoList() {

        return this.list();
    }

    @Override public CtUserInfoDto cTGetUserInfo(Long userInfoId) {
        UserInfo userInfo = this.getById(userInfoId);
        if(null == userInfo){
            throw new ApiException(-5,"用户不存在！");
        }
        CtUserInfoDto ctUserInfoDto = new CtUserInfoDto();
        ctUserInfoDto.setName(userInfo.getName());
        ctUserInfoDto.setIdNo(userInfo.getIdNo());
        ctUserInfoDto.setBornDate(userInfo.getBornDate());
        return ctUserInfoDto;
    }
}
